// -*- C++ -*-

// Get/set info about connection

// (C) Copyright 1994 Jeremy Fitzhardinge <jeremy@sw.oz.au>
// This code is distributed under the terms of the
// GNU General Public Licence.  See COPYING for more details.

#pragma implementation

#include <fstream.h>

#include "conninfo.h"
#include "ftpconn.h"

#include <sys/stat.h>

conninfo::conninfo(ftpfs &fs, ftpconn *c)
	 :ino(fs), conn(c)
{
	// Use our invoker's ID rather than the person doing the syscall.
	uid = getuid();
	gid = getgid();
	mode = S_IFREG | 0444;
	size = 0;
}

conninfo::~conninfo()
{
}

int
conninfo::do_read(const up_preamble &, upp_repl &,
		  const upp_read_s &arg, upp_read_r &ret)
{
	String s;
	
	conn->setparams();
	conn->conf.unparsestr(s);

	if (conn->lastreply != NULL)
	{
		s += "Last reply: ";
		s += *conn->lastreply + "\n";
	}
	
	cout << "arg.off="<<arg.off<<" arg.size="<<arg.size<<" str="<<s<<"\n";
	
	int sz = s.length() - arg.off;

	if (sz <= 0)
		sz = 0;

	sz = sz > arg.size ? arg.size : sz;

	ret.data.alloc(sz);
	ret.data.nelem = sz;
	memcpy(ret.data.elems, s.chars() + arg.off, sz);
	
	return 0;
}

int
conninfo::do_write(const up_preamble &, upp_repl &,
		   const upp_write_s &arg, upp_write_r &ret)
{
	ret.wrote = arg.data.nelem;
	
	return 0;
}
